@@ -1,4 +1,4 @@
-# @(#)$Id: Bob.pm 417 2012-11-13 20:13:07Z pjf $
+# @(#)Ident: Bob.pm 2013-03-29 19:16 pjf ;
 
 package Bob;
 
@@ -10,7 +10,7 @@ sub whimper { print {*STDOUT} $_[ 0 ]."\n"; exit 0 }
 
 BEGIN { my $reason; $reason = CPANTesting::should_abort and whimper $reason; }
 
-use version; our $VERSION = qv( '1.7' );
+use version; our $VERSION = qv( '1.8' );
 
 use File::Spec::Functions qw(catfile);
 use Module::Build;
@@ -33,6 +33,8 @@ sub new {
         create_license     => 1,
         create_packlist    => 0,
         create_readme      => 1,
+        create_readme_md   => defined $p->{create_readme_md}
+                              ? $p->{create_readme_md} : 1,
         dist_version_from  => $class_path,
         license            => $p->{license} || q(perl),
         meta_merge         => __get_resources( $p, $distname ),
@@ -46,6 +48,10 @@ sub new {
 
 # Private functions
 
+sub __is_src { # Is this the developer authoring a module?
+   return -f q(MANIFEST.SKIP);
+}
+
 sub __get_build_class { # Which subclass of M::B should we create?
    my $p = shift; exists $p->{build_class} and return $p->{build_class};
 
@@ -68,11 +74,13 @@ sub __get_cleanup_list {
 }
 
 sub __get_git_repository {
-   my ($info, $repo, $vcs); require Git::Class;
+   my ($repo, $vcs); require Git::Class;
 
    $vcs = Git::Class::Worktree->new( path => q(.) )
-      and $info = $vcs->git( q(remote) )
-      and $repo = ($info !~ m{ \A file: }mx) ? $info : undef
+      and $repo = (split q( ), (map  { s{ : }{/}mx; s{ @ }{://}mx; $_ }
+                                grep { m{ \A origin \s+ .+ fetch }mx }
+                                split  m{ [\n]  }mx,
+                                $vcs->git( qw(remote -v) ))[ 0 ])[ 1 ]
       and return $repo;
 
    return;
@@ -87,8 +95,11 @@ sub __get_no_index {
 sub __get_notes {
    my $p = shift; my $notes = exists $p->{notes} ? $p->{notes} : {};
 
+   # Optionally create README.md and / or README.pod files
+   $notes->{create_readme_md } = $p->{create_readme_md } || 0;
    $notes->{create_readme_pod} = $p->{create_readme_pod} || 0;
    $notes->{is_cpan_testing  } = CPANTesting::is_testing();
+   # Add a note to stop CPAN testing if requested in Build.PL
    $notes->{stop_tests       } = CPANTesting::test_exceptions( $p );
    $notes->{version          } = $VERSION;
    return $notes;
@@ -110,14 +121,13 @@ sub __get_resources {
                  ? $p->{bugtracker}
                  : q(http://rt.cpan.org/NoAuth/Bugs.html?Dist=);
    my $resources = $p->{resources} || {};
-   my $repo;
 
    $tracker and $resources->{bugtracker} = $tracker.$distname;
    $p->{home_page} and $resources->{homepage} = $p->{home_page};
    $resources->{license} ||= q(http://dev.perl.org/licenses/);
 
    # Only get repository info when authoring a distribution
-   -f q(MANIFEST.SKIP) and $repo = __get_repository
+   my $repo; __is_src and $repo = __get_repository
       and $resources->{repository} = $repo;
 
    return { resources => $resources };
